@@ -135,7 +135,7 @@ use strict;
 use vars qw( $VERSION @ISA );
 require 5.004;
 
-$VERSION = '1.0.13';
+$VERSION = '1.0.14';
 @ISA     = ();
 
 =head2 Tree::MultiNode::new
@@ -150,25 +150,23 @@ The first node will have no value (undef) in either it's key or it's value.
 
 =cut
 
-sub new
-{
-  my $this = shift;
-  my $class = ref($this) || $this;
-  my $self = {};
-  bless $self, $class;
+sub new {
+    my $this  = shift;
+    my $class = ref($this) || $this;
+    my $self  = {};
+    bless $self, $class;
 
-  $self->{'top'} = Tree::MultiNode::Node->new();
-  return $self;
+    $self->{'top'} = Tree::MultiNode::Node->new();
+    return $self;
 }
 
 #
 # this destructor is for clearing the circular references between
 # the tree, the nodes, and their children.
 #
-sub DESTROY
-{
-  my $self = shift;
-  $self->{'top'}->_clearrefs() if $self->{'top'};
+sub DESTROY {
+    my $self = shift;
+    $self->{'top'}->_clearrefs() if $self->{'top'};
 }
 
 1;
@@ -185,7 +183,6 @@ you should need to.  That being said, the interface is documented here anyway.
 
 =cut
 
-
 =head2 Tree::MultiNode::Node::new
 
   new($)
@@ -214,45 +211,44 @@ is stored as the key, and the second is stored as the value.
 
 =cut
 
-sub new 
-{
-  my $this = shift;
-  my $class = ref($this) || $this;
-  my $self = {};
-  bless $self, $class;
+sub new {
+    my $this  = shift;
+    my $class = ref($this) || $this;
+    my $self  = {};
+    bless $self, $class;
 
-  my $node = shift;
-  if( ref($node) eq "Tree::MultiNode::Node" ) {
-    # become a copy of that node...
-    $self->_clone($node);
-  }
-  else {
-    my($key,$value);
-    $key = $node;
-    $value = shift;
-    print __PACKAGE__, "::new() key,val = $key,$value\n" 
-      if $Tree::MultiNode::debug;
-    $self->{'children'} = [];
-    $self->{'parent'}   = undef;
-    $self->{'key'}      = $key || undef;
-    $self->{'value'}    = defined $value ? $value : undef;
-  }
+    my $node = shift;
+    if ( ref($node) eq "Tree::MultiNode::Node" ) {
 
-  return $self;
+        # become a copy of that node...
+        $self->_clone($node);
+    }
+    else {
+        my ( $key, $value );
+        $key   = $node;
+        $value = shift;
+        print __PACKAGE__, "::new() key,val = $key,$value\n"
+          if $Tree::MultiNode::debug;
+        $self->{'children'} = [];
+        $self->{'parent'}   = undef;
+        $self->{'key'}      = $key || undef;
+        $self->{'value'}    = defined $value ? $value : undef;
+    }
+
+    return $self;
 }
 
 #
 # internal method for making the current node a clone of another
 # node...
 #
-sub _clone
-{
-  my $self = shift;
-  my $them = shift;
-  $self->{'parent'}   = $them->parent;
-  $self->{'children'} = [$them->children];
-  $self->{'key'}      = $them->key;
-  $self->{'value'}    = $them->value;
+sub _clone {
+    my $self = shift;
+    my $them = shift;
+    $self->{'parent'}   = $them->parent;
+    $self->{'children'} = [ $them->children ];
+    $self->{'key'}      = $them->key;
+    $self->{'value'}    = $them->value;
 }
 
 =head2 Tree::MultiNode::Node::key
@@ -268,17 +264,16 @@ returned.
 
 =cut
 
-sub key
-{
-  my($self,$key) = @_;
+sub key {
+    my ( $self, $key ) = @_;
 
-  if(@_>1) {
-    print __PACKAGE__, "::key() setting key: $key on $self\n" 
-      if $Tree::MultiNode::debug;
-    $self->{'key'} = $key;
-  }
+    if ( @_ > 1 ) {
+        print __PACKAGE__, "::key() setting key: $key on $self\n"
+          if $Tree::MultiNode::debug;
+        $self->{'key'} = $key;
+    }
 
-  return $self->{'key'};
+    return $self->{'key'};
 }
 
 =head2 Tree::MultiNode::Node::value
@@ -294,18 +289,17 @@ returned.
 
 =cut
 
-sub value
-{
-  my $self = shift;
-  my $value = shift;
+sub value {
+    my $self  = shift;
+    my $value = shift;
 
-  if( defined $value ) {
-    print __PACKAGE__, "::value() setting value: $value on $self\n" 
-      if $Tree::MultiNode::debug;
-    $self->{'value'} = $value;
-  }
+    if ( defined $value ) {
+        print __PACKAGE__, "::value() setting value: $value on $self\n"
+          if $Tree::MultiNode::debug;
+        $self->{'value'} = $value;
+    }
 
-  return $self->{'value'};
+    return $self->{'value'};
 }
 
 =head2 Tree::MultiNode::Node::clear_key
@@ -318,10 +312,9 @@ Clears the key member by deleting it.
 
 =cut
 
-sub clear_key
-{
-  my $self = shift;
-  return delete $self->{'key'};
+sub clear_key {
+    my $self = shift;
+    return delete $self->{'key'};
 }
 
 =head2 Tree::MultiNode::Node::clear_value
@@ -334,10 +327,9 @@ Clears the value member by deleting it.
 
 =cut
 
-sub clear_value
-{
-  my $self = shift;
-  return delete $self->{'value'};
+sub clear_value {
+    my $self = shift;
+    return delete $self->{'value'};
 }
 
 =head2 Tree::MultiNode::Node::children
@@ -351,10 +343,9 @@ node object.
 
 =cut
 
-sub children 
-{
-  my $self = shift;
-  return $self->{'children'};
+sub children {
+    my $self = shift;
+    return $self->{'children'};
 }
 
 =head2 Tree::MultiNode::Node::child_keys  
@@ -370,46 +361,43 @@ from the child nodes.
 
 =cut
 
-sub child_keys
-{
-  my $self = shift;
-  my $children = $self->{'children'};
-  my @keys;
-  my $node;
+sub child_keys {
+    my $self     = shift;
+    my $children = $self->{'children'};
+    my @keys;
+    my $node;
 
-  foreach $node (@$children) {
-    push @keys, $node->key();
-  }
+    foreach $node (@$children) {
+        push @keys, $node->key();
+    }
 
-  return @keys;
+    return @keys;
 }
 
-sub child_values
-{
-  my $self = shift;
-  my $children = $self->{'children'};
-  my @values;
-  my $node;
+sub child_values {
+    my $self     = shift;
+    my $children = $self->{'children'};
+    my @values;
+    my $node;
 
-  foreach $node (@$children) {
-    push @values, $node->value();
-  }
+    foreach $node (@$children) {
+        push @values, $node->value();
+    }
 
-  return @values;
+    return @values;
 }
 
-sub child_kv_pairs
-{
-  my $self = shift;
-  my $children = $self->{'children'};
-  my %h;
-  my $node;
+sub child_kv_pairs {
+    my $self     = shift;
+    my $children = $self->{'children'};
+    my %h;
+    my $node;
 
-  foreach $node (@$children) {
-    $h{$node->key()} = $node->value();
-  }
+    foreach $node (@$children) {
+        $h{ $node->key() } = $node->value();
+    }
 
-  return %h;
+    return %h;
 }
 
 =head2 Tree::MultiNode::Node::child_key_positions  
@@ -423,21 +411,19 @@ of looking up the position of a given key in the child list.
 
 =cut
 
-sub child_key_positions
-{
-  my $self = shift;
-  my $children = $self->{'children'};
-  my(%h,$i,$node);
+sub child_key_positions {
+    my $self     = shift;
+    my $children = $self->{'children'};
+    my ( %h, $i, $node );
 
-  $i = 0;
-  foreach $node (@$children) {
-    $h{$node->key()} = $i++;
-  }
+    $i = 0;
+    foreach $node (@$children) {
+        $h{ $node->key() } = $i++;
+    }
 
-  return %h;
+    return %h;
 }
 
-
 =head2 Tree::MultiNode::Node::parent
 
 Returns a reference to the parent node of the current node.
@@ -446,10 +432,9 @@ Returns a reference to the parent node of the current node.
 
 =cut
 
-sub parent
-{
-  my $self = shift;
-  return $self->{'parent'};
+sub parent {
+    my $self = shift;
+    return $self->{'parent'};
 }
 
 =head2 Tree::MultiNode::Node::dump
@@ -460,24 +445,22 @@ Used for diagnostics, it prints out the members of the node.
 
 =cut
 
-sub dump
-{
-  my $self = shift;
+sub dump {
+    my $self = shift;
 
-  print "[dump] key:       ", $self->{'key'}, "\n";
-  print "[dump] val:       ", $self->{'value'}, "\n";
-  print "[dump] parent:    ", $self->{'parent'}, "\n";
-  print "[dump] children:  ", $self->{'children'}, "\n";
+    print "[dump] key:       ", $self->{'key'},      "\n";
+    print "[dump] val:       ", $self->{'value'},    "\n";
+    print "[dump] parent:    ", $self->{'parent'},   "\n";
+    print "[dump] children:  ", $self->{'children'}, "\n";
 }
 
-sub _clearrefs
-{
-  my $self = shift;
-  delete $self->{'parent'};
-  foreach my $child ( @{$self->children()} ) {
-    $child->_clearrefs();
-  }
-  delete $self->{'children'};
+sub _clearrefs {
+    my $self = shift;
+    delete $self->{'parent'};
+    foreach my $child ( @{ $self->children() } ) {
+        $child->_clearrefs();
+    }
+    delete $self->{'children'};
 }
 
 1;
@@ -521,51 +504,49 @@ Constructs a new handle.  You must pass a tree object to Handle::New.
 
 =cut
 
-sub new
-{
-  my $this = shift;
-  my $class = ref($this) || $this;
+sub new {
+    my $this  = shift;
+    my $class = ref($this) || $this;
 
-  my $self = {};
-  bless $self, $class;
-  my $data = shift;
-  print __PACKAGE__, "::new() ref($data) is: ", ref($data), "\n" 
-    if $Tree::MultiNode::debug;
-  if( ref($data) eq "Tree::MultiNode::Handle" ) {
-    $self->_clone($data);
-  }
-  else {
-    unless( ref($data) eq "Tree::MultiNode" ) {
-      confess "Error, invalid Tree::MultiNode reference:  $data\n";
+    my $self = {};
+    bless $self, $class;
+    my $data = shift;
+    print __PACKAGE__, "::new() ref($data) is: ", ref($data), "\n"
+      if $Tree::MultiNode::debug;
+    if ( ref($data) eq "Tree::MultiNode::Handle" ) {
+        $self->_clone($data);
     }
+    else {
+        unless ( ref($data) eq "Tree::MultiNode" ) {
+            confess "Error, invalid Tree::MultiNode reference:  $data\n";
+        }
 
-    $self->{'tree'}       = $data;
-    $self->{'curr_pos'}   = undef;
-    $self->{'curr_node'}  = $data->{'top'};
-    $self->{'curr_child'} = undef;
-    $self->{'curr_depth'} = 0;
-  }
-  return $self;
+        $self->{'tree'}       = $data;
+        $self->{'curr_pos'}   = undef;
+        $self->{'curr_node'}  = $data->{'top'};
+        $self->{'curr_child'} = undef;
+        $self->{'curr_depth'} = 0;
+    }
+    return $self;
 }
 
 #
 # internal method for making the current handle a copy of another
 # handle...
 #
-sub _clone
-{
-  my $self = shift;
-  my $them = shift;
-  print __PACKAGE__, "::_clone() cloning: $them\n" 
-    if $Tree::MultiNode::debug;
-  print __PACKAGE__, "::_clone() depth: ",$them->{'curr_depth'},"\n" 
-    if $Tree::MultiNode::debug;
-  $self->{'tree'}       = $them->{'tree'};
-  $self->{'curr_pos'}   = $them->{'curr_pos'};
-  $self->{'curr_node'}  = $them->{'curr_node'};
-  $self->{'curr_child'} = $them->{'curr_child'};
-  $self->{'curr_depth'} = $them->{'curr_depth'};
-  return 1;
+sub _clone {
+    my $self = shift;
+    my $them = shift;
+    print __PACKAGE__, "::_clone() cloning: $them\n"
+      if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::_clone() depth: ", $them->{'curr_depth'}, "\n"
+      if $Tree::MultiNode::debug;
+    $self->{'tree'}       = $them->{'tree'};
+    $self->{'curr_pos'}   = $them->{'curr_pos'};
+    $self->{'curr_node'}  = $them->{'curr_node'};
+    $self->{'curr_child'} = $them->{'curr_child'};
+    $self->{'curr_depth'} = $them->{'curr_depth'};
+    return 1;
 }
 
 =head2 Tree::MultiNode::Handle::tree
@@ -577,10 +558,9 @@ trying to create another node into the tree.
 
 =cut
 
-sub tree
-{
-  my $self = shift;
-  return $self->{'tree'};
+sub tree {
+    my $self = shift;
+    return $self->{'tree'};
 }
 
 =head2 Tree::MultiNode::Handle::get_data
@@ -591,12 +571,11 @@ Retrieves both the key, and value (as an array) for the current node.
 
 =cut
 
-sub get_data
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
+sub get_data {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
 
-  return($node->key,$node->value);
+    return ( $node->key, $node->value );
 }
 
 =head2 Tree::MultiNode::Handle::get_key
@@ -607,17 +586,16 @@ Retrieves the key for the current node.
 
 =cut
 
-sub get_key
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
+sub get_key {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
 
-  my $key = $node->key();
+    my $key = $node->key();
 
-  print __PACKAGE__, "::get_key() getting from $node : $key\n" 
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::get_key() getting from $node : $key\n"
+      if $Tree::MultiNode::debug;
 
-  return $key;
+    return $key;
 }
 
 =head2 Tree::MultiNode::Handle::set_key
@@ -628,16 +606,15 @@ Sets the key for the current node.
 
 =cut
 
-sub set_key
-{
-  my $self = shift;
-  my $key = shift;
-  my $node = $self->{'curr_node'};
+sub set_key {
+    my $self = shift;
+    my $key  = shift;
+    my $node = $self->{'curr_node'};
 
-  print __PACKAGE__, "::set_key() setting key \"$key\" on: $node\n" 
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::set_key() setting key \"$key\" on: $node\n"
+      if $Tree::MultiNode::debug;
 
-  return $node->key($key);
+    return $node->key($key);
 }
 
 =head2 Tree::MultiNode::Handle::get_value
@@ -648,17 +625,16 @@ Retrieves the value for the current node.
 
 =cut
 
-sub get_value
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
+sub get_value {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
 
-  my $value = $node->value();
+    my $value = $node->value();
 
-  print __PACKAGE__, "::get_value() getting from $node : $value\n",
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::get_value() getting from $node : $value\n",
+      if $Tree::MultiNode::debug;
 
-  return $value;
+    return $value;
 }
 
 =head2 Tree::MultiNode::Handle::set_value
@@ -669,16 +645,15 @@ Sets the value for the current node.
 
 =cut
 
-sub set_value
-{
-  my $self = shift;
-  my $value = shift;
-  my $node = $self->{'curr_node'};
+sub set_value {
+    my $self  = shift;
+    my $value = shift;
+    my $node  = $self->{'curr_node'};
 
-  print __PACKAGE__, "::set_value() setting value \"$value\" on: $node\n" 
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::set_value() setting value \"$value\" on: $node\n"
+      if $Tree::MultiNode::debug;
 
-  return $node->value($value);
+    return $node->value($value);
 }
 
 =head2 Tree::MultiNode::Handle::get_child
@@ -691,27 +666,26 @@ attempts to return the current child.  get_child returns a Node object.
 
 =cut
 
-sub get_child
-{
-  my $self = shift;
-  my $children = $self->{'curr_node'}->children;
-  my $pos = shift || $self->{'curr_pos'};
+sub get_child {
+    my $self     = shift;
+    my $children = $self->{'curr_node'}->children;
+    my $pos      = shift || $self->{'curr_pos'};
 
-  print __PACKAGE__, "::get_child() children: $children   $pos\n" 
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::get_child() children: $children   $pos\n"
+      if $Tree::MultiNode::debug;
 
-  unless( defined $children ) {
-    return undef;
-  }
+    unless ( defined $children ) {
+        return undef;
+    }
 
-  unless( defined $pos && $pos <= $#{$children} ) {
-    my $num = $#{$children};
-    confess "Error, $pos is an invalid position [$num] $children.\n";
-  }
+    unless ( defined $pos && $pos <= $#{$children} ) {
+        my $num = $#{$children};
+        confess "Error, $pos is an invalid position [$num] $children.\n";
+    }
 
-  print __PACKAGE__, "::get_child() returning [$pos]: ", 
-    ${$children}[$pos], "\n" if $Tree::MultiNode::debug;
-  return( ${$children}[$pos] );
+    print __PACKAGE__, "::get_child() returning [$pos]: ",
+      ${$children}[$pos], "\n" if $Tree::MultiNode::debug;
+    return ( ${$children}[$pos] );
 }
 
 =head2 Tree::MultiNode::Handle::add_child
@@ -733,40 +707,39 @@ the position specified.
 
 =cut
 
-sub add_child
-{
-  my $self = shift;
-  my($key,$value,$pos) = @_;
-  my $children = $self->{'curr_node'}->children;
-  print __PACKAGE__, "::add_child() children: $children\n" 
-    if $Tree::MultiNode::debug;
-  my $curr_pos = $self->{'curr_pos'};
-  my $curr_node = $self->{'curr_node'};
-
-  my $child = Tree::MultiNode::Node->new($key,$value);
-  $child->{'parent'} = $curr_node;
-
-  print __PACKAGE__, "::add_child() adding child $child ($key,$value) ",
-    "to: $children\n" if $Tree::MultiNode::debug;
-
-  if(defined $pos) {
-    print __PACKAGE__, "::add_child() adding at $pos $child\n" 
+sub add_child {
+    my $self = shift;
+    my ( $key, $value, $pos ) = @_;
+    my $children = $self->{'curr_node'}->children;
+    print __PACKAGE__, "::add_child() children: $children\n"
       if $Tree::MultiNode::debug;
-    unless($pos <= $#{$children}) {
-      my $num =  $#{$children};
-      confess "Position $pos is invalid for child position [$num] $children.\n";
+    my $curr_pos  = $self->{'curr_pos'};
+    my $curr_node = $self->{'curr_node'};
+
+    my $child = Tree::MultiNode::Node->new( $key, $value );
+    $child->{'parent'} = $curr_node;
+
+    print __PACKAGE__, "::add_child() adding child $child ($key,$value) ",
+      "to: $children\n" if $Tree::MultiNode::debug;
+
+    if ( defined $pos ) {
+        print __PACKAGE__, "::add_child() adding at $pos $child\n"
+          if $Tree::MultiNode::debug;
+        unless ( $pos <= $#{$children} ) {
+            my $num = $#{$children};
+            confess "Position $pos is invalid for child position [$num] $children.\n";
+        }
+        splice( @{$children}, $pos, 1, $child, ${$children}[$pos] );
+    }
+    else {
+        print __PACKAGE__, "::add_child() adding at end $child\n"
+          if $Tree::MultiNode::debug;
+        push @{$children}, $child;
     }
-    splice( @{$children}, $pos, 1, $child, ${$children}[$pos] );
-  }
-  else {
-    print __PACKAGE__, "::add_child() adding at end $child\n" 
-      if $Tree::MultiNode::debug;
-    push @{$children}, $child;
-  }
 
-  print __PACKAGE__, "::add_child() children:", 
-    join(',',@{$self->{'curr_node'}->children}), "\n" 
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__,                                  "::add_child() children:",
+      join( ',', @{ $self->{'curr_node'}->children } ), "\n"
+      if $Tree::MultiNode::debug;
 }
 
 =head2 Tree::MultiNode::Handle::add_child_node
@@ -781,46 +754,45 @@ Recently added via RT # 5435 -- Currently in need of proper documentation and te
 
 =cut
 
-sub add_child_node
-{
-  my $self = shift;
-  my($child,$pos) = @_;
-  my $children = $self->{'curr_node'}->children;
-  print __PACKAGE__, "::add_child_node() children: $children\n" 
-    if $Tree::MultiNode::debug;
-  my $curr_pos = $self->{'curr_pos'};
-  my $curr_node = $self->{'curr_node'};
-  if(ref($child) eq 'Tree::MultiNode') {
-    my $top = $child->{'top'};
-    $child->{'top'} = undef;
-    $child = $top;
-  }
-  confess "Invalid child argument.\n"
-    if(ref($child) ne 'Tree::MultiNode::Node');
-
-  $child->{'parent'} = $curr_node;
-
-  print __PACKAGE__, "::add_child_node() adding child $child ",
-    "to: $children\n" if $Tree::MultiNode::debug;
-
-  if(defined $pos) {
-    print __PACKAGE__, "::add_child_node() adding at $pos $child\n" 
+sub add_child_node {
+    my $self = shift;
+    my ( $child, $pos ) = @_;
+    my $children = $self->{'curr_node'}->children;
+    print __PACKAGE__, "::add_child_node() children: $children\n"
       if $Tree::MultiNode::debug;
-    unless($pos <= $#{$children}) {
-      my $num =  $#{$children};
-      confess "Position $pos is invalid for child position [$num] $children.\n";
+    my $curr_pos  = $self->{'curr_pos'};
+    my $curr_node = $self->{'curr_node'};
+    if ( ref($child) eq 'Tree::MultiNode' ) {
+        my $top = $child->{'top'};
+        $child->{'top'} = undef;
+        $child = $top;
     }
-    splice( @{$children}, $pos, 1, $child, ${$children}[$pos] );
-  }
-  else {
-    print __PACKAGE__, "::add_child_node() adding at end $child\n" 
-      if $Tree::MultiNode::debug;
-    push @{$children}, $child;
-  }
+    confess "Invalid child argument.\n"
+      if ( ref($child) ne 'Tree::MultiNode::Node' );
 
-  print __PACKAGE__, "::add_child_node() children:", 
-    join(',',@{$self->{'curr_node'}->children}), "\n" 
-    if $Tree::MultiNode::debug;
+    $child->{'parent'} = $curr_node;
+
+    print __PACKAGE__, "::add_child_node() adding child $child ",
+      "to: $children\n" if $Tree::MultiNode::debug;
+
+    if ( defined $pos ) {
+        print __PACKAGE__, "::add_child_node() adding at $pos $child\n"
+          if $Tree::MultiNode::debug;
+        unless ( $pos <= $#{$children} ) {
+            my $num = $#{$children};
+            confess "Position $pos is invalid for child position [$num] $children.\n";
+        }
+        splice( @{$children}, $pos, 1, $child, ${$children}[$pos] );
+    }
+    else {
+        print __PACKAGE__, "::add_child_node() adding at end $child\n"
+          if $Tree::MultiNode::debug;
+        push @{$children}, $child;
+    }
+
+    print __PACKAGE__,                                  "::add_child_node() children:",
+      join( ',', @{ $self->{'curr_node'}->children } ), "\n"
+      if $Tree::MultiNode::debug;
 }
 
 =head2 Tree::MultiNode::Handle::depth
@@ -831,16 +803,14 @@ Gets the depth for the current node.
 
 =cut
 
-sub depth
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
+sub depth {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
 
-  print __PACKAGE__, "::depth() getting depth \"$self->{'curr_depth'}\" ",
-    "on: $node\n" if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::depth() getting depth \"$self->{'curr_depth'}\" ",
+      "on: $node\n" if $Tree::MultiNode::debug;
 
-
-  return $self->{'curr_depth'};
+    return $self->{'curr_depth'};
 }
 
 =head2 Tree::MultiNode::Handle::select
@@ -864,26 +834,25 @@ false if they don't match, and true if they do.
 
 =cut
 
-sub select
-{
-  my $self = shift;
-  my $key  = shift;
-  my $code = shift || sub { return shift eq shift; } ;
-  my($child,$pos);
-  my $found = undef;
+sub select {
+    my $self = shift;
+    my $key  = shift;
+    my $code = shift || sub { return shift eq shift; };
+    my ( $child, $pos );
+    my $found = undef;
 
-  $pos = 0;
-  foreach $child ($self->children()) {
-    if( $code->($key,$child->key()) ) {
-      $self->{'curr_pos'}   = $pos;
-      $self->{'curr_child'} = $child;
-      ++$found;
-      last;
+    $pos = 0;
+    foreach $child ( $self->children() ) {
+        if ( $code->( $key, $child->key() ) ) {
+            $self->{'curr_pos'}   = $pos;
+            $self->{'curr_child'} = $child;
+            ++$found;
+            last;
+        }
+        ++$pos;
     }
-    ++$pos;
-  }
 
-  return $found;
+    return $found;
 }
 
 =head2 Tree::MultiNode::Handle::position
@@ -895,30 +864,29 @@ Sets, or retrieves the current child position.
 
 =cut
 
-sub position
-{
-  my $self = shift;
-  my $pos = shift;
+sub position {
+    my $self = shift;
+    my $pos  = shift;
 
-  print __PACKAGE__, "::position() $self  $pos\n" 
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::position() $self  $pos\n"
+      if $Tree::MultiNode::debug;
 
-  unless( defined $pos ) {
+    unless ( defined $pos ) {
+        return $self->{'curr_pos'};
+    }
+
+    my $children = $self->{'curr_node'}->children;
+    print __PACKAGE__, "::position() children: $children\n"
+      if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::position() position is $pos  ",
+      $#{$children}, "\n" if $Tree::MultiNode::debug;
+    unless ( $pos <= $#{$children} ) {
+        my $num = $#{$children};
+        confess "Error, $pos is invalid [$num] $children.\n";
+    }
+    $self->{'curr_pos'}   = $pos;
+    $self->{'curr_child'} = $self->get_child($pos);
     return $self->{'curr_pos'};
-  }
-
-  my $children = $self->{'curr_node'}->children;
-  print __PACKAGE__, "::position() children: $children\n" 
-    if $Tree::MultiNode::debug;
-  print __PACKAGE__, "::position() position is $pos  ",
-    $#{$children}, "\n" if $Tree::MultiNode::debug;
-  unless( $pos <= $#{$children} ) {
-    my $num = $#{$children};
-    confess "Error, $pos is invalid [$num] $children.\n";
-  }
-  $self->{'curr_pos'} = $pos;
-  $self->{'curr_child'} = $self->get_child($pos);
-  return $self->{'curr_pos'};
 }
 
 =head2 Tree::MultiNode::Handle::first
@@ -942,62 +910,58 @@ These functions will fail if there are no children for the current node.
 
 =cut
 
-sub first
-{
-  my $self = shift;
+sub first {
+    my $self = shift;
 
-  $self->{'curr_pos'}   = 0;
-  $self->{'curr_child'} = $self->get_child(0);
-  print __PACKAGE__, "::first() set child[",$self->{'curr_pos'},"]: ",
-    $self->{'curr_child'}, "\n" if $Tree::MultiNode::debug;
-  return $self->{'curr_pos'};
+    $self->{'curr_pos'}   = 0;
+    $self->{'curr_child'} = $self->get_child(0);
+    print __PACKAGE__, "::first() set child[", $self->{'curr_pos'}, "]: ",
+      $self->{'curr_child'}, "\n" if $Tree::MultiNode::debug;
+    return $self->{'curr_pos'};
 }
 
-sub next
-{
-  my $self = shift;
-  my $pos = $self->{'curr_pos'} + 1;
-  my $children = $self->{'curr_node'}->children;
-  print __PACKAGE__, "::next() children: $children\n" 
-    if $Tree::MultiNode::debug;
+sub next {
+    my $self     = shift;
+    my $pos      = $self->{'curr_pos'} + 1;
+    my $children = $self->{'curr_node'}->children;
+    print __PACKAGE__, "::next() children: $children\n"
+      if $Tree::MultiNode::debug;
 
-  unless( $pos >= 0 && $pos <= $#{$children} ) {
-    return undef;
-  }
+    unless ( $pos >= 0 && $pos <= $#{$children} ) {
+        return undef;
+    }
 
-  $self->{'curr_pos'}   = $pos;
-  $self->{'curr_child'} = $self->get_child($pos);
-  return $self->{'curr_pos'};
+    $self->{'curr_pos'}   = $pos;
+    $self->{'curr_child'} = $self->get_child($pos);
+    return $self->{'curr_pos'};
 }
 
-sub prev
-{
-  my $self = shift;
-  my $pos = $self->{'curr_pos'} - 1;
-  my $children = $self->{'curr_node'}->children;
-  print __PACKAGE__, "::prev() children: $children\n" 
-    if $Tree::MultiNode::debug;
+sub prev {
+    my $self     = shift;
+    my $pos      = $self->{'curr_pos'} - 1;
+    my $children = $self->{'curr_node'}->children;
+    print __PACKAGE__, "::prev() children: $children\n"
+      if $Tree::MultiNode::debug;
 
-  unless( $pos >= 0 && $pos <= $#{$children} ) {
-    return undef;
-  }
+    unless ( $pos >= 0 && $pos <= $#{$children} ) {
+        return undef;
+    }
 
-  $self->{'curr_pos'}   = $pos;
-  $self->{'curr_child'} = $self->get_child($pos);
-  return $self->{'curr_pos'};
+    $self->{'curr_pos'}   = $pos;
+    $self->{'curr_child'} = $self->get_child($pos);
+    return $self->{'curr_pos'};
 }
 
-sub last
-{
-  my $self = shift;
-  my $children = $self->{'curr_node'}->children;
-  my $pos = $#{$children};
-  print __PACKAGE__, "::last() children [$pos]: $children\n" 
-    if $Tree::MultiNode::debug;
+sub last {
+    my $self     = shift;
+    my $children = $self->{'curr_node'}->children;
+    my $pos      = $#{$children};
+    print __PACKAGE__, "::last() children [$pos]: $children\n"
+      if $Tree::MultiNode::debug;
 
-  $self->{'curr_pos'}   = $pos;
-  $self->{'curr_child'} = $self->get_child($pos);
-  return $self->{'curr_pos'};
+    $self->{'curr_pos'}   = $pos;
+    $self->{'curr_child'} = $self->get_child($pos);
+    return $self->{'curr_pos'};
 }
 
 =head2 Tree::MultiNode::Handle::down
@@ -1010,30 +974,29 @@ child becomes invalid (undef).
 
 =cut
 
-sub down
-{
-  my $self = shift;
-  my $pos = shift;
-  my $node = $self->{'curr_node'};
-  return undef unless defined $node;
-  my $children = $node->children;
-  print __PACKAGE__, "::down() children: $children\n" 
-    if $Tree::MultiNode::debug;
+sub down {
+    my $self = shift;
+    my $pos  = shift;
+    my $node = $self->{'curr_node'};
+    return undef unless defined $node;
+    my $children = $node->children;
+    print __PACKAGE__, "::down() children: $children\n"
+      if $Tree::MultiNode::debug;
 
-  if( defined $pos ) {
-    unless( defined $self->position($pos) ) {
-      confess "Error, $pos was an invalid position.\n";
+    if ( defined $pos ) {
+        unless ( defined $self->position($pos) ) {
+            confess "Error, $pos was an invalid position.\n";
+        }
     }
-  }
 
-  $self->{'curr_pos'}   = undef;
-  $self->{'curr_node'}  = $self->{'curr_child'};
-  $self->{'curr_child'} = undef;
-  ++$self->{'curr_depth'};
-  print __PACKAGE__, "::down() set to: ", $self->{'curr_node'}, "\n" 
-    if $Tree::MultiNode::debug;
+    $self->{'curr_pos'}   = undef;
+    $self->{'curr_node'}  = $self->{'curr_child'};
+    $self->{'curr_child'} = undef;
+    ++$self->{'curr_depth'};
+    print __PACKAGE__, "::down() set to: ", $self->{'curr_node'}, "\n"
+      if $Tree::MultiNode::debug;
 
-  return 1;
+    return 1;
 }
 
 =head2 Tree::MultiNode::Handle::up
@@ -1046,23 +1009,22 @@ invalid (undef).
 
 =cut
 
-sub up
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
-  return undef unless defined $node;
-  my $parent = $node->parent();
+sub up {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
+    return undef unless defined $node;
+    my $parent = $node->parent();
 
-  unless( defined $parent ) {
-    return undef;
-  }
-  
-  $self->{'curr_pos'}   = undef;
-  $self->{'curr_node'}  = $parent;
-  $self->{'curr_child'} = undef;
-  --$self->{'curr_depth'};
+    unless ( defined $parent ) {
+        return undef;
+    }
 
-  return 1;
+    $self->{'curr_pos'}   = undef;
+    $self->{'curr_node'}  = $parent;
+    $self->{'curr_child'} = undef;
+    --$self->{'curr_depth'};
+
+    return 1;
 }
 
 =head2 Tree::MultiNode::Handle::top
@@ -1074,17 +1036,16 @@ When top() is called, the current child becomes invalid (undef).
 
 =cut
 
-sub top
-{
-  my $self = shift;
-  my $tree = $self->{'tree'};
+sub top {
+    my $self = shift;
+    my $tree = $self->{'tree'};
 
-  $self->{'curr_pos'}   = undef;
-  $self->{'curr_node'}  = $tree->{'top'};
-  $self->{'curr_child'} = undef;
-  $self->{'curr_depth'} = 0;
+    $self->{'curr_pos'}   = undef;
+    $self->{'curr_node'}  = $tree->{'top'};
+    $self->{'curr_child'} = undef;
+    $self->{'curr_depth'} = 0;
 
-  return 1;
+    return 1;
 }
 
 =head2 Tree::MultiNode::Handle::children
@@ -1101,14 +1062,13 @@ the children of the current node.
 
 =cut
 
-sub children
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
-  return undef unless defined $node;
-  my $children = $node->children;
+sub children {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
+    return undef unless defined $node;
+    my $children = $node->children;
 
-  return @{$children};
+    return @{$children};
 }
 
 =head2 Tree::MultiNode::Handle::child_key_positions
@@ -1122,12 +1082,11 @@ of looking up the position of a given key in the child list.
 
 =cut
 
-sub child_key_positions
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
+sub child_key_positions {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
 
-  return $node->child_key_positions();
+    return $node->child_key_positions();
 }
 
 =head2 Tree::MultiNode::Handle::get_child_key
@@ -1139,14 +1098,13 @@ node.
 
 =cut
 
-sub get_child_key
-{
-  my $self = shift;
-  my $pos  = shift;
-  $pos = $self->{'curr_pos'} unless defined $pos;
+sub get_child_key {
+    my $self = shift;
+    my $pos  = shift;
+    $pos = $self->{'curr_pos'} unless defined $pos;
 
-  my $node = $self->get_child($pos);
-  return defined $node ? $node->key() : undef;
+    my $node = $self->get_child($pos);
+    return defined $node ? $node->key() : undef;
 }
 
 =head2 Tree::MultiNode::Handle::get_child_value
@@ -1158,15 +1116,14 @@ node.
 
 =cut
 
-sub get_child_value
-{
-  my $self = shift;
-  my $pos  = shift || $self->{'curr_pos'};
+sub get_child_value {
+    my $self = shift;
+    my $pos  = shift || $self->{'curr_pos'};
 
-  print __PACKAGE__, "::sub get_child_value() pos is: $pos\n" 
-    if $Tree::MultiNode::debug;
-  my $node = $self->get_child($pos);
-  return defined $node ? $node->value() : undef;
+    print __PACKAGE__, "::sub get_child_value() pos is: $pos\n"
+      if $Tree::MultiNode::debug;
+    my $node = $self->get_child($pos);
+    return defined $node ? $node->value() : undef;
 }
 
 =head2 Tree::MultiNode::Handle::remove_child
@@ -1178,40 +1135,38 @@ current node for this handle.
 
 =cut
 
-sub kv_pairs
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
+sub kv_pairs {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
 
-  return $node->child_kv_pairs();
+    return $node->child_kv_pairs();
 }
 
 =head2 Tree::MultiNode::Handle::remove_child
 
 =cut
 
-sub remove_child
-{
-  my $self = shift;
-  my $pos  = shift || $self->{'curr_pos'};
+sub remove_child {
+    my $self = shift;
+    my $pos  = shift || $self->{'curr_pos'};
 
-  print __PACKAGE__, "::remove_child() pos is: $pos\n"
-    if $Tree::MultiNode::debug;
+    print __PACKAGE__, "::remove_child() pos is: $pos\n"
+      if $Tree::MultiNode::debug;
 
-  my $children = $self->{'curr_node'}->children;
+    my $children = $self->{'curr_node'}->children;
 
-  unless( defined $children ) {
-    return undef;
-  }
+    unless ( defined $children ) {
+        return undef;
+    }
 
-  unless( defined $pos && $pos >= 0 && $pos <= $#{$children} ) {
-    my $num = $#{$children};
-    confess "Error, $pos is an invalid position [$num] $children.\n";
-  }
+    unless ( defined $pos && $pos >= 0 && $pos <= $#{$children} ) {
+        my $num = $#{$children};
+        confess "Error, $pos is an invalid position [$num] $children.\n";
+    }
 
-  my $node = splice(@{$children},$pos,1);
+    my $node = splice( @{$children}, $pos, 1 );
 
-  return ($node->key,$node->value);
+    return ( $node->key, $node->value );
 }
 
 =head2 Tree::MultiNode::Handle::child_keys
@@ -1221,12 +1176,11 @@ Returns undef if there is no current node.
 
 =cut
 
-sub child_keys
-{
-  my $self = shift;
-  my $node = $self->{'curr_node'};
-  return undef unless $node;
-  return $node->child_keys();
+sub child_keys {
+    my $self = shift;
+    my $node = $self->{'curr_node'};
+    return undef unless $node;
+    return $node->child_keys();
 }
 
 =head2 Tree::MultiNode::Handle::traverse
@@ -1249,27 +1203,25 @@ from the new node forward.
 
 =cut
 
-sub traverse
-{
-  my($self,$subref,@args) = @_;
-  confess "Error, invalid sub ref: $subref\n" unless 'CODE' eq ref($subref);
-  # operate on a cloned handle
-  return Tree::MultiNode::Handle->new($self)->_traverseImpl($subref,@args);
+sub traverse {
+    my ( $self, $subref, @args ) = @_;
+    confess "Error, invalid sub ref: $subref\n" unless 'CODE' eq ref($subref);
+
+    # operate on a cloned handle
+    return Tree::MultiNode::Handle->new($self)->_traverseImpl( $subref, @args );
 }
 
-sub _traverseImpl
-{
-  my($self,$subref,@args) = @_;
-  $subref->( @args, $self );
-  for(my $i = 0; $i < scalar($self->children); ++$i ) {
-    $self->down($i);
-      $self->_traverseImpl($subref,@args);
-    $self->up();
-  }
-  return;
+sub _traverseImpl {
+    my ( $self, $subref, @args ) = @_;
+    $subref->( @args, $self );
+    for ( my $i = 0; $i < scalar( $self->children ); ++$i ) {
+        $self->down($i);
+        $self->_traverseImpl( $subref, @args );
+        $self->up();
+    }
+    return;
 }
 
-
 =head2 Tree::MultiNode::Handle::traverse
  or to have
 the subref to be a method on an object (and still pass the object's 
@@ -1288,27 +1240,25 @@ the subref to be a method on an object (and still pass the object's
   }
 =cut
 
-sub otraverse
-{
-  my($self,$subref,@args) = @_;
-  confess "Error, invalid sub ref: $subref\n" unless 'CODE' eq ref($subref);
-  # operate on a cloned handle
-  return Tree::MultiNode::Handle->new($self)->_otraverseImpl($subref,@args);
+sub otraverse {
+    my ( $self, $subref, @args ) = @_;
+    confess "Error, invalid sub ref: $subref\n" unless 'CODE' eq ref($subref);
+
+    # operate on a cloned handle
+    return Tree::MultiNode::Handle->new($self)->_otraverseImpl( $subref, @args );
 }
 
-sub _otraverseImpl
-{
-  my($self,$obj,$method,@args) = @_;
-  $obj->$method( @args, $self );
-  for(my $i = 0; $i < scalar($self->children); ++$i ) {
-    $self->down($i);
-      $self->_otraverseImpl($obj,$method,@args);
-    $self->up();
-  }
-  return;
+sub _otraverseImpl {
+    my ( $self, $obj, $method, @args ) = @_;
+    $obj->$method( @args, $self );
+    for ( my $i = 0; $i < scalar( $self->children ); ++$i ) {
+        $self->down($i);
+        $self->_otraverseImpl( $obj, $method, @args );
+        $self->up();
+    }
+    return;
 }
 
-
 =head1 SEE ALSO
 
 Algorithms in C++
